/*  File src/changestats_duration.h in package tergm, part of the Statnet suite
 *  of packages for network analysis, http://statnet.org .
 *
 *  This software is distributed under the GPL-3 license.  It is free,
 *  open source, and has the attribution requirements (GPL Section 7) at
 *  http://statnet.org/attribution
 *
 *  Copyright 2003-2014 Statnet Commons
 */
#ifndef CHANGESTATS_DURATION_H
#define CHANGESTATS_DURATION_H

#include "edgetree.h"
#include "changestat.h"
D_CHANGESTAT_FN(d_competitor_log_age);

D_CHANGESTAT_FN(d_log_ages);

D_CHANGESTAT_FN(d_edges_ageinterval);
D_CHANGESTAT_FN(d_edges_ageinterval_mon);
S_CHANGESTAT_FN(s_edges_ageinterval_mon);

D_CHANGESTAT_FN(d_edge_ages_mon);
S_CHANGESTAT_FN(s_edge_ages_mon);

D_CHANGESTAT_FN(d_edgecov_ages_mon);
S_CHANGESTAT_FN(s_edgecov_ages_mon);

D_CHANGESTAT_FN(d_mean_age_mon);
S_CHANGESTAT_FN(s_mean_age_mon);

D_CHANGESTAT_FN(d_edgecov_mean_age_mon);
S_CHANGESTAT_FN(s_edgecov_mean_age_mon);

#endif








